% Generated by roxygen2 (4.0.1): do not edit by hand
\name{gg_interaction.ggRandomForests}
\alias{gg_interaction}
\alias{gg_interaction.ggRandomForests}
\title{Minimal Depth Variable Interaction data object.}
\usage{
gg_interaction.ggRandomForests(object, ...)
}
\arguments{
\item{object}{a randomForestSRC object or the output from the
\code{find.interaction} function call.}

\item{...}{optional extra arguments passed to find.interaction.}
}
\description{
Basically, this function adds attributes to the results of running
\code{find.interaction} on an \code{rfsrc} random forest. If passed  a
\code{rfsrc} object, gg_interaction first runs the \code{find.interaction}
function with all optional arguments.
}
\examples{
## Examples from RFSRC package...
## ------------------------------------------------------------
## find interactions, survival setting
## ------------------------------------------------------------
## data(pbc, package = "randomForestSRC")
## pbc.obj <- rfsrc(Surv(days,status) ~ ., pbc, nsplit = 10)
## pbc_interaction <- find.interaction(pbc.obj, nvar = 8)
data(pbc_interaction, package="ggRandomForests")
gg_int <- gg_interaction(pbc_interaction)

plot(gg_int, x_var="bili")
plot(gg_int, x_var="copper")


## ------------------------------------------------------------
## find interactions, regression setting
## ------------------------------------------------------------
## airq.obj <- rfsrc(Ozone ~ ., data = airquality)
##
## TODO: VIMP interactions not handled yet....
## find.interaction(airq.obj, method = "vimp", nrep = 3)
## airq_interaction <- find.interaction(airq.obj)
data(airq_interaction, package="ggRandomForests")
gg_int <- gg_interaction(airq_interaction)

plot(gg_int, x_var="Temp")
plot(gg_int, x_var="Solar.R")


## ------------------------------------------------------------
## find interactions, classification setting
## ------------------------------------------------------------
## iris.obj <- rfsrc(Species ~., data = iris)
## TODO: VIMP interactions not handled yet....
## find.interaction(iris.obj, method = "vimp", nrep = 3)
## iris_interaction <- find.interaction(iris.obj)
data(iris_interaction, package="ggRandomForests")
gg_int <- gg_interaction(iris_interaction)

plot(gg_int, x_var="Petal.Width")
plot(gg_int, x_var="Petal.Length")
}
\references{
Ishwaran H. (2007). Variable importance in binary regression trees and
forests, Electronic J. Statist., 1:519-537.

Ishwaran H., Kogalur U.B., Gorodeski E.Z, Minn A.J. and Lauer M.S. (2010).
High-dimensional variable selection for survival data. J. Amer. Statist.
Assoc., 105:205-217.

Ishwaran H., Kogalur U.B., Chen X. and Minn A.J. (2011). Random survival
forests for high-dimensional data. Statist. Anal. Data Mining, 4:115-132.
}
\seealso{
\code{find.interaction} \code{max.subtree} \code{var.select} \code{vimp}
}

