% Generated by roxygen2 (4.0.1): do not edit by hand
\name{gg_variable.ggRandomForests}
\alias{gg_variable}
\alias{gg_variable.ggRandomForests}
\alias{gg_variable.rfsrc}
\title{Marginal variable depedence data object.}
\usage{
gg_variable.ggRandomForests(object, time, time.labels, oob = TRUE, ...)
}
\arguments{
\item{object}{a randomForestSRC object}

\item{time}{point (or points) of interest (for survival forests only)}

\item{time.labels}{If more than one time is specified, a vector of time.labels
for differentiating the time points (for survival forests only)}

\item{oob}{indicate if predicted results should include oob or full data set.}

\item{...}{extra arguments}
}
\value{
A matrix for creating the marginal variable dependence plots.
}
\description{
\code{plot.variable} generates a data.frame containing the marginal
variable dependance or the partial variable dependence. The \code{gg_variable}
function creates a data.frame of containing the full set of covariate data
(predictor variables) and the predicted response for each observation. Marginal
dependence figures are created using the \code{\link{plot.gg_variable}} function.
}
\details{
The marginal variable dependence is determined by comparing relation
between the predicted response from the randomforest and a covariate of interest.

The gg_variable function operates on a randomForestSRC object, or the output
from the \code{plot.variable} function.
}
\examples{
## ------------------------------------------------------------
## survival examples
## ------------------------------------------------------------

## survival
# data(veteran, package = "randomForestSRC")
# veteran_rf <- rfsrc(Surv(time,status)~., veteran, nsplit = 10, ntree = 100)
data(veteran_rf, package="ggRandomForests")

# get the 1 year survival time.
ggrf.obj <- gg_variable(veteran_rf, time=1)

#plot.variable(v.obj, plots.per.page = 3)
plot(ggrf.obj)

#plot.variable(v.obj, plots.per.page = 2, xvar.names = c("trt", "karno", "age"))
plot.gg_variable(ggrf.obj, c("trt", "karno", "age"))

#plot.variable(v.obj, surv.type = "surv", nvar = 1, time = 200)
ggrf.obj <- gg_variable(veteran_rf, time=200)
plot.gg_variable(ggrf.obj, "age")
## ------------------------------------------------------------
## regression
## ------------------------------------------------------------

## airquality
#airq.obj <- rfsrc(Ozone ~ ., data = airquality)
data(airq_rf, package="ggRandomForests")

# plot.variable(airq.obj, partial = TRUE, smooth.lines = TRUE)

## motor trend cars
#mtcars.obj <- rfsrc(mpg ~ ., data = mtcars)
data(mtcars_rf, package="ggRandomForests")
# plot.variable(mtcars.obj, partial = TRUE, smooth.lines = TRUE)

## ------------------------------------------------------------
## classification
## ------------------------------------------------------------

## iris
#iris.obj <- rfsrc(Species ~., data = iris)
data(iris_rf, package="ggRandomForests")

#plot.variable(iris.obj, partial = TRUE)
}
\seealso{
\code{\link{plot.gg_variable}} \code{plot.variable}
}

