% Generated by roxygen2 (4.0.1): do not edit by hand
\name{plot.gg_rfsrc}
\alias{plot.gg_rfsrc}
\title{Predicted response plot generic function, operates on a
\code{\link{gg_rfsrc}} object.}
\usage{
\method{plot}{gg_rfsrc}(x, ...)
}
\arguments{
\item{x}{gg_rfsrc object created from a randomForestSRC object}

\item{...}{arguments passed to \code{\link{gg_rfsrc}}.}
}
\value{
ggplot object
}
\description{
Plot the predicted response from a \code{\link{gg_rfsrc}} object, the
random forest prediction, using the OOB prediction from the forest.
}
\examples{
\dontrun{
## ------------------------------------------------------------
## classification example
## ------------------------------------------------------------
iris.obj <- rfsrc(Species ~ ., data = iris)
ggrf.obj<- gg_rfsrc(iris.obj)

plot.gg_rfsrc(ggrf.obj)

## ------------------------------------------------------------
## Regression example
## ------------------------------------------------------------
airq.obj <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
ggrf.obj<- gg_rfsrc(airq.obj)

plot.gg_rfsrc(ggrf.obj)

## ------------------------------------------------------------
## Survival example
## ------------------------------------------------------------
## veteran data
## randomized trial of two treatment regimens for lung cancer
data(veteran, package = "randomForestSRCM")
v.obj <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)

ggrf.obj <- gg_rfsrc(v.obj)
plot(ggrf.obj)
}
}
\references{
Breiman L. (2001). Random forests, Machine Learning, 45:5-32.

Ishwaran H. and Kogalur U.B. (2007). Random survival forests for
R, Rnews, 7(2):25-31.

Ishwaran H. and Kogalur U.B. (2013). Random Forests for Survival, Regression
and Classification (RF-SRC), R package version 1.4.
}
\seealso{
\code{\link{gg_rfsrc}} \code{rfsrc}
}

